Skip to contents

Apply the SciDataReportR qualitative palette to the color aesthetic in a ggplot. Use this scale for categorical groups represented by points, lines, outlines, or other color-mapped geometries.

Usage

scale_color_SciData(...)

Arguments

...

Additional arguments passed to ggplot2::scale_color_manual().

Value

A ggplot2 discrete color scale.

Examples

ggplot2::ggplot(
  iris,
  ggplot2::aes(
    x = Sepal.Length,
    y = Sepal.Width,
    color = Species
  )
) +
  ggplot2::geom_point() +
  scale_color_SciData()