Skip to contents

Copies the get-started R script template to the working directory.

Usage

use_GetStartedScript(filename = "Scripts/script_GetStarted.R")

Arguments

filename

The name to save the R script as (default: "Scripts/script_GetStarted.R").

Value

Invisibly returns filename after copying the template. Called for its side effect of creating the script file.