Skip to contents

This function adds a caption to a ggplot explaining the meaning of star annotations (*, **, ***). It is most commonly added to correlation heatmaps produced by PlotCorrelationsHeatmap() or to downstream plots derived from that function with add_r_and_stars().

Usage

geom_starcaption()

Value

A labs() object that can be added to a ggplot, especially SciDataReportR heatmaps that use star annotations.

Input requirements

geom_starcaption() does not take an input object directly. Add it to a ggplot with +, typically a plot returned inside the list created by PlotCorrelationsHeatmap() or a plot returned by add_r_and_stars().