This function reverses the levels of specified categorical variables in a given dataframe.
Usage
reverseFactorLevels(data, variables, df = lifecycle::deprecated())This function reverses the levels of specified categorical variables in a given dataframe.
reverseFactorLevels(data, variables, df = lifecycle::deprecated())