Copies the EDATemplate template to the working directory.
Usage
use_EDATemplate(filename = "Reports/EDA_Report.qmd")
Arguments
- filename
The name to save the Quarto file as (default:
"Reports/EDA_Report.qmd").
Value
Invisibly returns filename after copying the template. Called
for its side effect of creating the report file.